@@ -7,12 +7,12 @@ Usage: python split-file.py prefix filename
 """
 
 import sys
+from pathlib import Path
 
 prefix = sys.argv[1]
 filename = sys.argv[2]
-f = open(filename)
 sf = None
-for line in f:
+for line in Path(filename).read_text().splitlines():
     if line.startswith('Processing database:'):
         if sf:
             sf.close()
@@ -29,12 +29,11 @@ for line in f:
                 complib = param
         if 'PyTables' in prefix:
             if complib:
-                sfilename = "%s-O%s-%s.out" % (prefix, optlevel, complib)
+                sfilename = f"{prefix}-O{optlevel}-{complib}.out"
             else:
-                sfilename = "%s-O%s.out" % (prefix, optlevel,)
+                sfilename = f"{prefix}-O{optlevel}.out"
         else:
-            sfilename = "%s.out" % (prefix,)
+            sfilename = f"{prefix}.out"
         sf = file(sfilename, 'a')
     if sf:
         sf.write(line)
-f.close()
