@@ -1,14 +1,13 @@
-from __future__ import print_function
 import numpy as np
-import tables
+import tables as tb
 
 # Open a new empty HDF5 file
-fileh = tables.open_file("array2.h5", mode="w")
+fileh = tb.open_file("array2.h5", mode="w")
 # Shortcut to the root group
 root = fileh.root
 
 # Create an array
-a = np.array([1, 2.7182818284590451, 3.141592], float)
+a = np.array([1, np.e, np.pi], float)
 print("About to write array:", a)
 print("  with shape: ==>", a.shape)
 print("  and dtype ==>", a.dtype)
@@ -24,7 +23,7 @@ print("Info on the object:", repr(root.carray))
 fileh.close()
 
 # Open the previous HDF5 file in read-only mode
-fileh = tables.open_file("array2.h5", mode="r")
+fileh = tb.open_file("array2.h5", mode="r")
 # Get the root group
 root = fileh.root
 
